@@ -29,18 +29,22 @@ if False:
     winerror, win32api, isbsd, config_dir
 
 _mt_inited = False
+
+
 def _init_mimetypes():
     global _mt_inited
     import mimetypes
     mimetypes.init([P('mime.types')])
     _mt_inited = True
 
+
 def guess_type(*args, **kwargs):
     import mimetypes
     if not _mt_inited:
         _init_mimetypes()
     return mimetypes.guess_type(*args, **kwargs)
 
+
 def guess_all_extensions(*args, **kwargs):
     import mimetypes
     if not _mt_inited:
@@ -57,17 +61,20 @@ def guess_extension(*args, **kwargs):
         ext = '.pdb'
     return ext
 
+
 def get_types_map():
     import mimetypes
     if not _mt_inited:
         _init_mimetypes()
     return mimetypes.types_map
 
+
 def to_unicode(raw, encoding='utf-8', errors='strict'):
     if isinstance(raw, unicode):
         return raw
     return raw.decode(encoding, errors)
 
+
 def patheq(p1, p2):
     p = os.path
     d = lambda x : p.normcase(p.normpath(p.realpath(p.normpath(x))))
@@ -75,6 +82,7 @@ def patheq(p1, p2):
         return False
     return d(p1) == d(p2)
 
+
 def unicode_path(path, abs=False):
     if isinstance(path, bytes):
         path = path.decode(filesystem_encoding)
@@ -82,6 +90,7 @@ def unicode_path(path, abs=False):
         path = os.path.abspath(path)
     return path
 
+
 def osx_version():
     if isosx:
         import platform
@@ -90,6 +99,7 @@ def osx_version():
         if m:
             return int(m.group(1)), int(m.group(2)), int(m.group(3))
 
+
 def confirm_config_name(name):
     return name + '_again'
 
@@ -97,6 +107,7 @@ _filename_sanitize = re.compile(r'[\xae\0\\|\?\*<":>\+/]')
 _filename_sanitize_unicode = frozenset([u'\\', u'|', u'?', u'*', u'<',
     u'"', u':', u'>', u'+', u'/'] + list(map(unichr, xrange(32))))
 
+
 def sanitize_file_name(name, substitute='_', as_unicode=False):
     '''
     Sanitize the filename `name`. All invalid characters are replaced by `substitute`.
@@ -125,6 +136,7 @@ def sanitize_file_name(name, substitute='_', as_unicode=False):
         one = '_' + one[1:]
     return one
 
+
 def sanitize_file_name_unicode(name, substitute='_'):
     '''
     Sanitize the filename `name`. All invalid characters are replaced by `substitute`.
@@ -151,6 +163,7 @@ def sanitize_file_name_unicode(name, substitute='_'):
         one = '_' + one[1:]
     return one
 
+
 def sanitize_file_name2(name, substitute='_'):
     '''
     Sanitize filenames removing invalid chars. Keeps unicode names as unicode
@@ -160,6 +173,7 @@ def sanitize_file_name2(name, substitute='_'):
         return sanitize_file_name(name, substitute=substitute)
     return sanitize_file_name_unicode(name, substitute=substitute)
 
+
 def prints(*args, **kwargs):
     '''
     Print unicode arguments safely by encoding them to preferred_encoding
@@ -227,9 +241,11 @@ def prints(*args, **kwargs):
     count += len(sep)
     return count
 
+
 class CommandLineError(Exception):
     pass
 
+
 def setup_cli_handlers(logger, level):
     import logging
     if os.environ.get('CALIBRE_WORKER', None) is not None and logger.handlers:
@@ -261,6 +277,7 @@ def load_library(name, cdll):
         return cdll.LoadLibrary(name)
     return cdll.LoadLibrary(name+'.so')
 
+
 def filename_to_utf8(name):
     '''Return C{name} encoded in utf8. Unhandled characters are replaced. '''
     if isinstance(name, unicode):
@@ -268,6 +285,7 @@ def filename_to_utf8(name):
     codec = 'cp1252' if iswindows else 'utf8'
     return name.decode(codec, 'replace').encode('utf8')
 
+
 def extract(path, dir):
     extractor = None
     # First use the file header to identify its type
@@ -292,6 +310,7 @@ def extract(path, dir):
         raise Exception('Unknown archive type')
     extractor(path, dir)
 
+
 def get_proxies(debug=True):
     from urllib import getproxies
     proxies = getproxies()
@@ -315,6 +334,7 @@ def get_proxies(debug=True):
         prints('Using proxies:', proxies)
     return proxies
 
+
 def get_parsed_proxy(typ='http', debug=True):
     proxies = get_proxies(debug)
     proxy = proxies.get(typ, None)
@@ -346,6 +366,7 @@ def get_parsed_proxy(typ='http', debug=True):
                     prints('Using http proxy', str(ans))
                 return ans
 
+
 def get_proxy_info(proxy_scheme, proxy_string):
     '''
     Parse all proxy information from a proxy string (as returned by
@@ -368,7 +389,8 @@ def get_proxy_info(proxy_scheme, proxy_string):
         return None
     return ans
 
-USER_AGENT = 'Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.13) Gecko/20101210 Gentoo Firefox/3.6.13'
+# IE 11 on windows 7
+USER_AGENT = 'Mozilla/5.0 (Windows NT 6.1; Trident/7.0; rv:11.0) like Gecko'
 USER_AGENT_MOBILE = 'Mozilla/5.0 (Windows; U; Windows CE 5.1; rv:1.8.1a3) Gecko/20060610 Minimo/0.016'
 
 
@@ -398,6 +420,7 @@ def random_user_agent(choose=None):
             ]
     return random.choice(ua_list) if choose is None else ua_list[choose]
 
+
 def browser(honor_time=True, max_time=2, mobile_browser=False, user_agent=None, use_robust_parser=False, verify_ssl_certificates=True):
     '''
     Create a mechanize browser for web scraping. The browser handles cookies,
@@ -431,6 +454,7 @@ def browser(honor_time=True, max_time=2, mobile_browser=False, user_agent=None,
 
     return opener
 
+
 def fit_image(width, height, pwidth, pheight):
     '''
     Fit image in box of width pwidth and height pheight.
@@ -453,6 +477,7 @@ def fit_image(width, height, pwidth, pheight):
 
     return scaled, int(width), int(height)
 
+
 class CurrentDir(object):
 
     def __init__(self, path, workaround_temp_folder_permissions=False):
@@ -481,6 +506,8 @@ class CurrentDir(object):
 
 
 _ncpus = None
+
+
 def detect_ncpus():
     """Detects the number of effective CPUs in the system"""
     global _ncpus
@@ -502,18 +529,22 @@ def detect_ncpus():
 
 relpath = os.path.relpath
 _spat = re.compile(r'^the\s+|^a\s+|^an\s+', re.IGNORECASE)
+
+
 def english_sort(x, y):
     '''
     Comapare two english phrases ignoring starting prepositions.
     '''
     return cmp(_spat.sub('', x), _spat.sub('', y))
 
+
 def walk(dir):
     ''' A nice interface to os.walk '''
     for record in os.walk(dir):
         for f in record[-1]:
             yield os.path.join(record[0], f)
 
+
 def strftime(fmt, t=None):
     ''' A version of strftime that returns unicode strings and tries to handle dates
     before 1900 '''
@@ -542,12 +573,14 @@ def strftime(fmt, t=None):
         ans = ans.replace('_early year hack##', str(orig_year))
     return ans
 
+
 def my_unichr(num):
     try:
         return safe_chr(num)
     except (ValueError, OverflowError):
         return u'?'
 
+
 def entity_to_unicode(match, exceptions=[], encoding='cp1252',
         result_exceptions={}):
     '''
@@ -606,12 +639,15 @@ xml_entity_to_unicode = partial(entity_to_unicode, result_exceptions={
     '>' : '&gt;',
     '&' : '&amp;'})
 
+
 def replace_entities(raw, encoding='cp1252'):
     return _ent_pat.sub(partial(entity_to_unicode, encoding=encoding), raw)
 
+
 def xml_replace_entities(raw, encoding='cp1252'):
     return _ent_pat.sub(partial(xml_entity_to_unicode, encoding=encoding), raw)
 
+
 def prepare_string_for_xml(raw, attribute=False):
     raw = _ent_pat.sub(entity_to_unicode, raw)
     raw = raw.replace('&', '&amp;').replace('<', '&lt;').replace('>', '&gt;')
@@ -619,9 +655,11 @@ def prepare_string_for_xml(raw, attribute=False):
         raw = raw.replace('"', '&quot;').replace("'", '&apos;')
     return raw
 
+
 def isbytestring(obj):
     return isinstance(obj, (str, bytes))
 
+
 def force_unicode(obj, enc=preferred_encoding):
     if isbytestring(obj):
         try:
@@ -639,6 +677,7 @@ def force_unicode(obj, enc=preferred_encoding):
                         obj = obj.decode('utf-8')
     return obj
 
+
 def as_unicode(obj, enc=preferred_encoding):
     if not isbytestring(obj):
         try:
@@ -650,12 +689,14 @@ def as_unicode(obj, enc=preferred_encoding):
                 obj = repr(obj)
     return force_unicode(obj, enc=enc)
 
+
 def url_slash_cleaner(url):
     '''
     Removes redundant /'s from url's.
     '''
     return re.sub(r'(?<!:)/{2,}', '/', url)
 
+
 def human_readable(size, sep=' '):
     """ Convert a size in bytes into a human readable form """
     divisor, suffix = 1, "B"
@@ -670,6 +711,7 @@ def human_readable(size, sep=' '):
         size = size[:-2]
     return size + sep + suffix
 
+
 def remove_bracketed_text(src,
         brackets={u'(':u')', u'[':u']', u'{':u'}'}):
     from collections import Counter
@@ -688,10 +730,12 @@ def remove_bracketed_text(src,
             buf.append(char)
     return u''.join(buf)
 
+
 def ipython(user_ns=None):
     from calibre.utils.ipython import ipython
     ipython(user_ns=user_ns)
 
+
 def fsync(fileobj):
     fileobj.flush()
     os.fsync(fileobj.fileno())
