@@ -19,25 +19,28 @@ from PyQt5.Qt import (
     QMimeData, QUrl, QDrag, QPoint, QPainter, QRect, pyqtProperty, QEvent,
     QPropertyAnimation, QEasingCurve, pyqtSlot, QHelpEvent, QAbstractItemView,
     QStyleOptionViewItem, QToolTip, QByteArray, QBuffer, QBrush, qRed, qGreen,
-    qBlue, QItemSelectionModel, QIcon)
+    qBlue, QItemSelectionModel, QIcon, QFont)
 
 from calibre import fit_image, prints, prepare_string_for_xml, human_readable
 from calibre.constants import DEBUG, config_dir
-from calibre.ebooks.metadata import fmt_sidx
+from calibre.ebooks.metadata import fmt_sidx, rating_to_stars
 from calibre.utils import join_with_timeout
-from calibre.gui2 import gprefs, config
+from calibre.gui2 import gprefs, config, rating_font
 from calibre.gui2.library.caches import CoverCache, ThumbnailCache
 from calibre.utils.config import prefs, tweaks
 
 CM_TO_INCH = 0.393701
 CACHE_FORMAT = 'PPM'
 
+
 def auto_height(widget):
     return max(185, QApplication.instance().desktop().availableGeometry(widget).height() / 5.0)
 
+
 class EncodeError(ValueError):
     pass
 
+
 def image_to_data(image):  # {{{
     ba = QByteArray()
     buf = QBuffer(ba)
@@ -50,14 +53,18 @@ def image_to_data(image):  # {{{
 # }}}
 
 # Drag 'n Drop {{{
+
+
 def dragMoveEvent(self, event):
     event.acceptProposedAction()
 
+
 def event_has_mods(self, event=None):
     mods = event.modifiers() if event is not None else \
             QApplication.keyboardModifiers()
     return mods & Qt.ControlModifier or mods & Qt.ShiftModifier
 
+
 def mousePressEvent(base_class, self, event):
     ep = event.pos()
     if self.indexAt(ep) in self.selectionModel().selectedIndexes() and \
@@ -67,6 +74,7 @@ def mousePressEvent(base_class, self, event):
         return self.handle_mouse_press_event(event)
     return base_class.mousePressEvent(self, event)
 
+
 def drag_icon(self, cover, multiple):
     cover = cover.scaledToHeight(120, Qt.SmoothTransformation)
     if multiple:
@@ -95,6 +103,7 @@ def drag_icon(self, cover, multiple):
         cover = base
     return QPixmap.fromImage(cover)
 
+
 def drag_data(self):
     m = self.model()
     db = m.db
@@ -138,6 +147,7 @@ def drag_data(self):
     drag.setPixmap(cover)
     return drag
 
+
 def mouseMoveEvent(base_class, self, event):
     if not self.drag_allowed:
         return
@@ -160,6 +170,7 @@ def mouseMoveEvent(base_class, self, event):
     drag.exec_(Qt.CopyAction)
     self.drag_start_pos = None
 
+
 def dragEnterEvent(self, event):
     if int(event.possibleActions() & Qt.CopyAction) + \
         int(event.possibleActions() & Qt.MoveAction) == 0:
@@ -169,12 +180,14 @@ def dragEnterEvent(self, event):
     if paths:
         event.acceptProposedAction()
 
+
 def dropEvent(self, event):
     paths = self.paths_from_event(event)
     event.setDropAction(Qt.CopyAction)
     event.accept()
     self.files_dropped.emit(paths)
 
+
 def paths_from_event(self, event):
     '''
     Accept a drop event and return a list of paths that can be read from
@@ -187,6 +200,7 @@ def paths_from_event(self, event):
         return [u for u in urls if os.path.splitext(u)[1] and
                 os.path.exists(u)]
 
+
 def setup_dnd_interface(cls_or_self):
     if isinstance(cls_or_self, type):
         cls = cls_or_self
@@ -210,6 +224,8 @@ def setup_dnd_interface(cls_or_self):
 # }}}
 
 # Manage slave views {{{
+
+
 def sync(func):
     @wraps(func)
     def ans(self, *args, **kwargs):
@@ -219,6 +235,7 @@ def sync(func):
             return func(self, *args, **kwargs)
     return ans
 
+
 class AlternateViews(object):
 
     def __init__(self, main_view):
@@ -309,6 +326,8 @@ class AlternateViews(object):
 # }}}
 
 # Rendering of covers {{{
+
+
 class CoverDelegate(QStyledItemDelegate):
 
     MARGIN = 4
@@ -333,6 +352,7 @@ class CoverDelegate(QStyledItemDelegate):
         self.render_queue = LifoQueue()
         self.animating = None
         self.highlight_color = QColor(Qt.white)
+        self.rating_font = QFont(rating_font())
 
     def set_dimensions(self):
         width = self.original_width = gprefs['cover_grid_width']
@@ -384,6 +404,7 @@ class CoverDelegate(QStyledItemDelegate):
         return self.item_size
 
     def render_field(self, db, book_id):
+        is_stars = False
         try:
             field = db.pref('field_under_covers_in_grid', 'title')
             if field == 'size':
@@ -392,13 +413,14 @@ class CoverDelegate(QStyledItemDelegate):
                 mi = db.get_proxy_metadata(book_id)
                 display_name, ans, val, fm = mi.format_field_extended(field)
                 if fm and fm['datatype'] == 'rating':
-                    ans = u'\u2605' * int(val/2.0) if val is not None else ''
-            return '' if ans is None else unicode(ans)
+                    ans = rating_to_stars(val, fm['display'].get('allow_half_stars', False))
+                    is_stars = True
+            return ('' if ans is None else unicode(ans)), is_stars
         except Exception:
             if DEBUG:
                 import traceback
                 traceback.print_exc()
-        return ''
+        return '', is_stars
 
     def render_emblem(self, book_id, rule, rule_index, cache, mi, db, formatter, template_cache):
         ans = cache[book_id].get(rule, False)
@@ -420,7 +442,7 @@ class CoverDelegate(QStyledItemDelegate):
         if raw_icon is not None:
             ans = raw_icon.pixmap(sz, sz)
         elif name == ':ondevice':
-            ans = QIcon(I('ok.png')).scaled(sz, sz)
+            ans = QIcon(I('ok.png')).pixmap(sz, sz)
         elif name:
             pmap = QIcon(os.path.join(config_dir, 'cc_icons', name)).pixmap(sz, sz)
             if not pmap.isNull():
@@ -497,7 +519,9 @@ class CoverDelegate(QStyledItemDelegate):
                     rect = trect
                     rect.setTop(rect.bottom() - self.title_height + 5)
                     painter.setRenderHint(QPainter.TextAntialiasing, True)
-                    title = self.render_field(db, book_id)
+                    title, is_stars = self.render_field(db, book_id)
+                    if is_stars:
+                        painter.setFont(self.rating_font)
                     metrics = painter.fontMetrics()
                     painter.setPen(self.highlight_color)
                     painter.drawText(rect, Qt.AlignCenter|Qt.TextSingleLine,
@@ -601,6 +625,8 @@ class CoverDelegate(QStyledItemDelegate):
 # }}}
 
 # The View {{{
+
+
 @setup_dnd_interface
 class GridView(QListView):
 
@@ -627,7 +653,7 @@ class GridView(QListView):
         self.padding_left = 0
         self.set_color()
         self.ignore_render_requests = Event()
-        dpr = self.devicePixelRatio()
+        dpr = self.device_pixel_ratio
         self.thumbnail_cache = ThumbnailCache(max_size=gprefs['cover_grid_disk_cache_size'],
             thumbnail_size=(int(dpr * self.delegate.cover_size.width()), int(dpr * self.delegate.cover_size.height())))
         self.render_thread = None
@@ -644,6 +670,13 @@ class GridView(QListView):
         t.setInterval(200), t.setSingleShot(True)
         t.timeout.connect(self.update_memory_cover_cache_size)
 
+    @property
+    def device_pixel_ratio(self):
+        try:
+            return self.devicePixelRatioF()
+        except AttributeError:
+            return self.devicePixelRatio()
+
     @property
     def first_visible_row(self):
         geom = self.viewport().geometry()
@@ -728,7 +761,7 @@ class GridView(QListView):
             self.setSpacing(self.delegate.spacing)
         self.set_color()
         if size_changed:
-            dpr = self.devicePixelRatio()
+            dpr = self.device_pixel_ratio
             self.thumbnail_cache.set_thumbnail_size(int(dpr * self.delegate.cover_size.width()), int(dpr*self.delegate.cover_size.height()))
         cs = gprefs['cover_grid_disk_cache_size']
         if (cs*(1024**2)) != self.thumbnail_cache.max_size:
@@ -793,7 +826,7 @@ class GridView(QListView):
         if has_cover:
             p = QImage()
             p.loadFromData(cdata, CACHE_FORMAT if cdata is tcdata else 'JPEG')
-            dpr = self.devicePixelRatio()
+            dpr = self.device_pixel_ratio
             p.setDevicePixelRatio(dpr)
             if p.isNull() and cdata is tcdata:
                 # Invalid image in cache
